"use client"
import React, { useState, useEffect } from "react";
import { useSidebar, useThemeStore } from "@/store";
import { cn } from "@/lib/utils";
import Link from "next/link";
import { useMediaQuery } from "@/hooks/use-media-query";
import MobileFooter from "./mobile-footer";
import FooterLayout from "./footer-layout";
import { useMounted } from "@/hooks/use-mounted";
import { useTranslations } from "next-intl";
import { getApiData } from "@/Helper/common";

const Footer = ({ handleOpenSearch }) => {
  const lang = useTranslations("Footer");

  const { collapsed, sidebarType, showText } = useSidebar();
  const { layout, footerType } = useThemeStore();
  const mounted = useMounted();
  const isMobile = useMediaQuery("(min-width: 768px)");

  if (!mounted) {
    return null;
  }
  if (!isMobile && sidebarType === "module") {
    return <MobileFooter handleOpenSearch={handleOpenSearch} />;
  }

  if (footerType === "hidden") {
    return null;
  }

  if (layout === "semibox") {
    return (
      <div className="xl:mx-20 mx-6">
        <FooterLayout
          className={cn(" rounded-md border", {
            "xl:ml-[140px]": collapsed,
            "xl:ml-[272px]": !collapsed,
            "sticky bottom-0": footerType === "sticky",
          })}
        >
          <FooterContent />
        </FooterLayout>
      </div>
    );
  }
  if (sidebarType !== "module" && layout !== "horizontal") {
    return (
      <FooterLayout
        className={cn("", {
          "xl:ml-[420px]": !collapsed && !showText,
          "xl:ml-[200px]": collapsed && !showText,
          "xl:ml-[290px]": !collapsed && showText,
          "xl:ml-[66px]": collapsed && showText,
          "sticky bottom-0": footerType === "sticky",

        })}
      >
        <FooterContent />
      </FooterLayout>
    );
  }

  if (layout === "horizontal") {
    return (
      <FooterLayout
        className={cn("", {
          "sticky bottom-0": footerType === "sticky",
        })}
      >
        <FooterContent />
      </FooterLayout>
    );
  }

  return (
    <FooterLayout
      className={cn("", {
        "xl:ml-[412px]": !collapsed,
        "xl:ml-[140px]": collapsed,
        "sticky bottom-0": footerType === "sticky",

      })}
    >
      <FooterContent />
    </FooterLayout>
  );
};

export default Footer;

const FooterContent = () => {

  const [data, setData] = useState(null);

  var apiCall = true;

  const fetchData = async () => {
    try {

      if (apiCall) {

        apiCall = false;

        const apiResData = await getApiData("theme-setting/single");

        if (apiResData.error === false) {
          setData(apiResData.result);
        } else {
          setData([])
        }
      }
    } catch (error) {
      console.error("Error fetching:", error);
    } finally {

    }
  };

  useEffect(() => {
    fetchData();
  }, []);

  const lang = useTranslations("Footer");
  return (
    <div className="block md:flex md:justify-between text-muted-foreground">
      <p className="sm:mb-0 text-xs md:text-sm flex">
        {new Date().getFullYear()} {data?.company_name} All Right Reserved &nbsp;{data?.design_developed_link ? <a href={data?.design_developed_link}>({data?.design_developed})</a> : ''}
      </p>

    </div>
  );
};
